==> afflib-3.2.0.tar.gz: afflib-3.2.0/tools/test_signing.sh <==
#!/bin/sh
# 
# test the signing tools

/bin/rm -f agent.pem analyst.pem archives.pem evidence.*

echo === MAKING THE TEST FILES ===
dd if=/dev/zero of=blank.iso bs=65536 count=20
./afconvert blank.iso

dd if=/dev/urandom of=rawevidence.iso bs=65536 count=24
dd if=/dev/zero of=r2.iso bs=65536 count=24
cat r2.iso >> rawevidence.iso
rm r2.iso
touch r3.iso
for fn in /usr/share/dict/* ; do cat $fn >> r3.iso ; done
for i in `yes | head -10` ; do cat r3.iso >> rawevidence.iso ; done
rm r3.iso

echo === Putting a new metadata segment into blank.aff  ===
./afsegment -ssegname=testseg1 blank.aff
if [ x"testseg1" = x`./afsegment -p segname blank.aff` ] ; then 
  echo afsegment worked!
else
  echo afsegment does not work properly
  exit 1
fi

echo ==== AFSIGN TEST ===
echo Making X.509 keys

openssl req -x509 -newkey rsa:1024 -keyout agent.pem -out agent.pem -nodes -subj "/C=US/ST=California/L=Remote/O=Country Govt./OU=Sherif Dept/CN=Mr. Agent/emailAddress=agent@investiations.com"

 openssl req -x509 -newkey rsa:1024 -keyout analyst.pem -out analyst.pem -nodes -subj "/C=US/ST=California/L=Remote/O=State Police/OU=Forensics/CN=Ms. Analyst/emailAddress=analyst@investiations.com"
openssl req -x509 -newkey rsa:1024 -keyout archives.pem -out archives.pem -nodes -subj "/C=US/ST=CA/L=Remote/O=Archives/OU=Electronic/CN=Dr. Librarian/emailAddress=drbits@investiations.com"

echo Making an AFF file to sign
rm -f evidence.aff evidence?.aff
./afconvert -o evidence.aff rawevidence.iso 
if ! ./afsign -k agent.pem evidence.aff ; then echo afsign failed ; exit 1 ; fi 
if ! ./afverify evidence.aff ; then echo afverify failed ; exit 1 ; fi ; 

echo Signature test 1 passed
echo Testing chain-of-custody signatures

if ! ./afcopy -z -s agent.pem rawevidence.iso evidence.aff ; then exit 1; fi
if ! ./afinfo -a evidence.aff ; then exit 1 ; fi
if ! ./afcompare rawevidence.iso evidence.aff ; then exit 1 ; fi
if ! ./afverify evidence.aff ; then exit 1 ; fi

echo
echo Making the second generation copy
echo "This copy was made by the analyst" | ./afcopy -z -s analyst.pem -n evidence.aff evidence2.aff
if ! ./afinfo -a evidence2.aff ; then exit 1 ; fi
if ! ./afcompare rawevidence.iso evidence2.aff ; then exit 1 ; fi
if ! ./afverify evidence2.aff ; then exit 1 ; fi
echo
echo Making the third generation copy
echo "This copy was made by the archives" | ./afcopy -z -s archives.pem -n evidence2.aff evidence3.aff
if ! ./afinfo -a evidence3.aff ; then exit 1 ; fi
if ! ./afcompare rawevidence.iso evidence3.aff ; then exit 1 ; fi
if ! ./afverify evidence3.aff ; then exit 1 ; fi


echo All tests passed successfully
echo Erasing temporary files.
rm -f agent.pem archives.pem analyst.pem evidence.aff evidence.afm rawevidence.iso cevidence.iso evidence2.aff evidence3.aff evidence.aff
exit 0

==> afflib-3.2.5.tar.gz: afflib-3.2.5/tools/test_signing.sh <==
#!/bin/sh
# 
# test the signing tools

/bin/rm -f agent.pem analyst.pem archives.pem evidence.aff evidence2.aff evidence3.aff
unset AFFLIB_PASSPHRASE

echo === MAKING THE TEST FILES ===

PATH=$PATH:../tools:../../tools:.
test_make_random_iso.sh rawevidence.iso

echo ==== AFSIGN TEST ===
echo Making X.509 keys

openssl req -x509 -newkey rsa:1024 -keyout agent.pem -out agent.pem -nodes -subj "/C=US/ST=California/L=Remote/O=Country Govt./OU=Sherif Dept/CN=Mr. Agent/emailAddress=agent@investiations.com"

 openssl req -x509 -newkey rsa:1024 -keyout analyst.pem -out analyst.pem -nodes -subj "/C=US/ST=California/L=Remote/O=State Police/OU=Forensics/CN=Ms. Analyst/emailAddress=analyst@investiations.com"
openssl req -x509 -newkey rsa:1024 -keyout archives.pem -out archives.pem -nodes -subj "/C=US/ST=CA/L=Remote/O=Archives/OU=Electronic/CN=Dr. Librarian/emailAddress=drbits@investiations.com"

echo Making an AFF file to sign
rm -f evidence.aff evidence?.aff
./afconvert -o evidence.aff rawevidence.iso 
echo Initial AFF file
if ! ./afinfo -a evidence.aff ; then exit 1 ; fi

echo Signing AFF file...
if ! ./afsign -k agent.pem evidence.aff ; then echo afsign failed ; exit 1 ; fi 
if ! ./afverify evidence.aff ; then echo afverify failed ; exit 1 ; fi ; 

echo Signature test 1 passed

echo Testing chain-of-custody signatures
echo Copying original raw file to evidence1.aff

if ! ./afcopy -z -k agent.pem rawevidence.iso evidence1.aff ; then exit 1; fi
if ! ./afinfo -a evidence1.aff ; then exit 1 ; fi
if ! ./afcompare rawevidence.iso evidence1.aff ; then exit 1 ; fi
if ! ./afverify evidence1.aff ; then exit 1 ; fi

echo
echo Making the second generation copy
echo "This copy was made by the analyst" | ./afcopy -z -k analyst.pem -n evidence1.aff evidence2.aff
if ! ./afinfo -a evidence2.aff ; then exit 1 ; fi
if ! ./afcompare rawevidence.iso evidence2.aff ; then exit 1 ; fi
if ! ./afverify evidence2.aff ; then exit 1 ; fi
echo
echo Making the third generation copy
echo "This copy was made by the archives" | ./afcopy -z -k archives.pem -n evidence2.aff evidence3.aff
if ! ./afinfo -a evidence3.aff ; then exit 1 ; fi
if ! ./afcompare rawevidence.iso evidence3.aff ; then exit 1 ; fi
if ! ./afverify evidence3.aff ; then exit 1 ; fi


echo All tests passed successfully
echo Erasing temporary files.
rm -f agent.pem archives.pem analyst.pem evidence.aff evidence.afm rawevidence.iso cevidence.iso evidence2.aff evidence3.aff evidence.aff
exit 0
